@@ -4,7 +4,7 @@
 */
 
 /*
-** $Id: cgi.c,v 1.36 2007/05/01 03:01:57 mrsam Exp $
+** $Id: cgi.c,v 1.37 2009/06/27 16:32:38 mrsam Exp $
 */
 #include	<stdio.h>
 #include	<stdlib.h>
@@ -643,7 +643,13 @@ int cgi_getfiles( int (*start_file)(const char *, const char *, void *),
 		int (*file)(const char *, size_t, void *),
 		void (*end_file)(void *), size_t filenum, void *voidarg)
 {
-struct cgigetfileinfo gfi={start_file, file, end_file, filenum, voidarg};
+	struct cgigetfileinfo gfi;
+
+	gfi.start_file=start_file;
+	gfi.file=file;
+	gfi.end_file=end_file;
+	gfi.filenum=filenum;
+	gfi.voidarg=voidarg;
 
 	if (rfc2045p) rfc2045_decode(rfc2045p, &cgifiledecode, &gfi);
 	if (gfi.filenum)	return (-1);
