@@ -61,7 +61,7 @@
 #include	"sysconfdir.h"
 #include	"localstatedir.h"
 
-static const char rcsid[]="$Id: ldapaliasd.c,v 1.25 2006/05/28 15:29:51 mrsam Exp $";
+static const char rcsid[]="$Id: ldapaliasd.c,v 1.28 2006/11/12 15:33:23 mrsam Exp $";
 
 static LDAP *my_ldap_fp=0;
 static const char *basedn;
@@ -117,7 +117,7 @@ static void ldapclose()
 {
 	if (my_ldap_fp)
 	{
-		ldap_unbind(my_ldap_fp);
+		ldap_unbind_ext(my_ldap_fp, NULL, NULL);
 		my_ldap_fp=0;
 	}
 }
@@ -141,15 +141,13 @@ static LDAP *ldapconnect()
 {
 	LDAP	*p;
 
-	const char *hostname_s=ldapaliasd_config("LDAP_SERVER");
-	const char *port_s=ldapaliasd_config("LDAP_PORT");
-	int port;
+	const char *url_s=ldapaliasd_config("LDAP_URI");
 
-	if (!*hostname_s || (port=atoi(port_s)) <= 0)
+	if (!*url_s)
 	{
 #if	HAVE_SYSLOG_H
 		syslog(LOG_DAEMON|LOG_CRIT,
-		       "Cannot read LDAP_SERVER and LDAP_PORT from %s",
+		       "Cannot read LDAP_URI from %s",
 		       LDAPALIASDCONFIGFILE);
 #endif
 		return (0);
@@ -158,14 +156,12 @@ static LDAP *ldapconnect()
 	if (ldapconncheck())
 		return (NULL);
 
-	p=ldap_init((char *)hostname_s, port);
-
-	if (p==NULL)
+	if (ldap_initialize(&p, url_s) != LDAP_SUCCESS)
 	{
 #if	HAVE_SYSLOG_H
 		syslog(LOG_DAEMON|LOG_CRIT,
-			"Cannot connect to %s, port %d: %s",
-			hostname_s, port, strerror(errno));
+			"Cannot connect to %s: %s",
+			url_s, strerror(errno));
 #endif
 		ldapconnfailure();
 	}
@@ -177,6 +173,7 @@ static int ldapopen()
 	int     ldrc;
 	const char *binddn_s=ldapaliasd_config("LDAP_BINDDN");
 	const char *bindpw_s=ldapaliasd_config("LDAP_BINDPW");
+	struct berval cred;
 
 	basedn=ldapaliasd_config("LDAP_BASEDN");
 
@@ -210,8 +207,13 @@ static int ldapopen()
 		return (0);
 	}
 
-	if (ldaperror(ldrc = ldap_simple_bind_s(my_ldap_fp,
-		(char *)binddn_s, (char *)bindpw_s)) != LDAP_SUCCESS)
+	cred.bv_len=strlen(bindpw_s ? bindpw_s:"");
+	cred.bv_val=bindpw_s ? (char *)bindpw_s:"";
+
+
+	if (ldaperror(ldrc = ldap_sasl_bind_s(my_ldap_fp, binddn_s, NULL,
+					      &cred, NULL, NULL, NULL))
+	    != LDAP_SUCCESS)
 	{
 		const char *s=ldap_err2string(ldrc);
 
@@ -238,11 +240,14 @@ static LDAPMessage *search_attr_retry(const char *filter, const char *attr)
 	timeout.tv_sec=timeout_n;
 	timeout.tv_usec=0;
 
-	if (ldaperror(ldap_search_st(my_ldap_fp, (char *)basedn,
-				     LDAP_SCOPE_SUBTREE,
-				     (char *)filter, attrlist, 0,
-				     &timeout, &result)
-		      != LDAP_SUCCESS))
+	if (ldaperror(ldap_search_ext_s(my_ldap_fp, (char *)basedn,
+					LDAP_SCOPE_SUBTREE,
+					(char *)filter, attrlist,
+					0,
+					NULL, NULL, &timeout,
+					1000000,
+					&result))
+	    != LDAP_SUCCESS)
 		return (NULL);
 	return (result);
 }
@@ -323,23 +328,29 @@ static int search_maildrop(const char *mail, const char *source, FILE *outfp)
 	if (ldap_count_entries(my_ldap_fp, result) == 1)
 	{
 		LDAPMessage *entry;
-		char **values;
+		struct berval **values;
 
 		if ((entry=ldap_first_entry(my_ldap_fp, result)) != NULL &&
-		    (values=ldap_get_values(my_ldap_fp, entry,
-					    (char *)
-					    maildropfield)) != NULL)
+		    (values=ldap_get_values_len(my_ldap_fp, entry,
+						(char *)
+						maildropfield)) != NULL)
 		{
-			int n=ldap_count_values(values);
+			int n=ldap_count_values_len(values);
 			int i;
 
 			for (i=0; i<n; i++)
 			{
-				fprintf(outfp, "maildrop: %s\n",
-					values[i]);
+				int rc;
+
+				fprintf(outfp, "maildrop: ");
+				if ((rc=fwrite(values[i]->bv_val,
+					       values[i]->bv_len,
+					       1, outfp)) < 0)
+					break;
+				fprintf(outfp, "\n");
 				rc=0;
 			}
-			ldap_value_free(values);
+			ldap_value_free_len(values);
 		}
 	}
 	ldap_msgfree(result);
@@ -430,23 +441,30 @@ static int search_virtual(const char *mail, const char *source, FILE *outfp)
 	if (ldap_count_entries(my_ldap_fp, result) == 1)
 	{
 		LDAPMessage *entry;
-		char **values;
+		struct berval **values;
 
 		if ((entry=ldap_first_entry(my_ldap_fp, result)) != NULL &&
-		    (values=ldap_get_values(my_ldap_fp, entry,
-					    (char *)
-					    vuser)) != NULL)
+		    (values=ldap_get_values_len(my_ldap_fp, entry,
+						(char *)
+						vuser)) != NULL)
 		{
-			int n=ldap_count_values(values);
+			int n=ldap_count_values_len(values);
 			int i;
 
 			for (i=0; i<n; i++)
 			{
-				fprintf(outfp, "maildrop: %s-%s\n",
-					values[i], filter);
+				int rc;
+
+				fprintf(outfp, "maildrop: ");
+				if ((rc=fwrite(values[i]->bv_val,
+					       values[i]->bv_len,
+					       1, outfp)) < 0)
+					break;
+
+				fprintf(outfp, "-%s\n", filter);
 				rc=0;
 			}
-			ldap_value_free(values);
+			ldap_value_free_len(values);
 		}
 	}
 	ldap_msgfree(result);
