@@ -41,7 +41,7 @@
 #include	<courierauth.h>
 #include	<courierauthsasl.h>
 
-static const char rcsid[]="$Id: courieresmtpd.c,v 1.54 2008/06/30 00:31:15 mrsam Exp $";
+static const char rcsid[]="$Id: courieresmtpd.c,v 1.56 2009/07/13 22:06:31 mrsam Exp $";
 
 static char helobuf[256];
 static char authuserbuf[256];
@@ -56,7 +56,7 @@ static int hasstarttls;
 static char *mailfroms=0;
 extern time_t iovread_timeout;
 extern time_t iovwrite_timeout;
-static char *input_line;
+static char *input_line="";
 static void cancelsubmit();
 static time_t data_timeout;
 
@@ -91,6 +91,10 @@ void iov_logerror(const char *q, const char *p)
 {
 	const char *ident=getenv("TCPREMOTEINFO");
 
+	if (strcmp(input_line, "QUIT") == 0)
+		return;
+	/* Do not log write errors for QUIT cmd -- broken clients */
+
 	clog_msg_start_info();
 	clog_msg_str("error,relay=");
 	clog_msg_str(tcpremoteip);
