@@ -54,7 +54,7 @@
 #include	"liblock/liblock.h"
 #include	"liblock/mail.h"
 
-static const char rcsid[]="$Id: deliver.c,v 1.25 2008/11/26 03:57:28 mrsam Exp $";
+static const char rcsid[]="$Id: deliver.c,v 1.26 2009/06/27 16:32:38 mrsam Exp $";
 
 extern char *local_dotcourier(const char *, const char *, const char **);
 extern char *local_extension();
@@ -549,7 +549,7 @@ struct maildir_tmpcreate_info createInfo;
 		delivery_error("out of memory.");
 	}
 
-	maildir_closequotafile(&quotainfo);	// For now.
+	maildir_closequotafile(&quotainfo);	/* For now. */
 
 	sprintf(buf, "%u", ++counter);
 
