@@ -36,10 +36,12 @@
 #include	<courierauthdebug.h>
 #include	"tcpd/spipe.h"
 #include	"numlib/numlib.h"
+#include	"tcpd/tlsclient.h"
 
-static const char rcsid[]="$Id: imaplogin.c,v 1.34 2008/02/11 01:13:09 mrsam Exp $";
+static const char rcsid[]="$Id: imaplogin.c,v 1.36 2008/06/29 20:18:36 mrsam Exp $";
 
 FILE *debugfile=0;
+extern void initcapability();
 extern void mainloop();
 extern void imapcapability();
 extern int have_starttls();
@@ -69,9 +71,12 @@ extern void cmdsuccess(const char *, const char *);
 
 static int	starttls(const char *tag)
 {
-int	pipefd[2];
-pid_t	p;
-int	waitstat;
+	char *argvec[4];
+
+	char localfd_buf[NUMBUFSIZE+40];
+	char buf2[NUMBUFSIZE];
+	struct couriertls_info cinfo;
+	int pipefd[2];
 
 	if (libmail_streampipe(pipefd))
 	{
@@ -79,51 +84,34 @@ int	waitstat;
 		return (-1);
 	}
 
-	p=fork();
-	if (p == -1)
-	{
-		cmdfail(tag, "fork() failed.\r\n");
-		return (-1);
-	}
+	couriertls_init(&cinfo);
+	fcntl(pipefd[0], F_SETFD, FD_CLOEXEC);
 
-	if (p == 0)
-	{
-	char	buf1[100];
-	char	dummy;
+	strcat(strcpy(localfd_buf, "-localfd="),
+	       libmail_str_size_t(pipefd[1], buf2));
 
-		/*
-		** Fork once more, and let the parent exit,
-		** so that courieresmtpd doesn't have this
-		** child process.
-		*/
-
-		p=fork();
-		if (p == -1)
-		{
-			perror("fork");
-			exit(1);
-		}
-		if (p)	exit(0);
-
-		close(pipefd[0]);
-		sprintf(buf1, "-localfd=%d", (int)pipefd[1]);
-		if (read(pipefd[1], &dummy, 1) != 1)
-			exit(0);
-
-		/* couriertls will have the socket on fd 0,
-		** and dup stderr on fd 1 */
-
-		dup2(2, 1);
-		alarm(0);
-		execl( getenv("COURIERTLS"), "couriertls",
-			buf1, "-tcpd", "-server", (char *)0);
-		fprintf(stderr, "ERR: COURIERTLS exec(%s) failed!!\n",
-					 getenv("COURIERTLS"));
-		exit(1);
-	}
+	argvec[0]=localfd_buf;
+	argvec[1]="-tcpd";
+	argvec[2]="-server";
+	argvec[3]=NULL;
 
 	cmdsuccess(tag, "Begin SSL/TLS negotiation now.\r\n");
 	writeflush();
+
+	if (couriertls_start(argvec, &cinfo))
+	{
+		close(pipefd[0]);
+		close(pipefd[1]);
+		cmdfail(tag, "STARTTLS failed: ");
+		writes(cinfo.errmsg);
+		writes("\r\n");
+		couriertls_destroy(&cinfo);
+		return (-1);
+	}
+
+	couriertls_export_subject_environment(&cinfo);
+	couriertls_destroy(&cinfo);
+
 	close(pipefd[1]);
 	close(0);
 	close(1);
@@ -133,11 +121,6 @@ int	waitstat;
 		exit(1);
 	}
 	close(pipefd[0]);
-	if (write(1, "", 1) < 0)	/* child - exec OK now */
-		; /* make gcc shut up */
-
-	while (wait(&waitstat) != p)
-		;
 
 	/* We use select() with a timeout, so use non-blocking filedescs */
 
@@ -312,7 +295,7 @@ int do_imap_command(const char *tag)
 	if (strcmp(curtoken->tokenbuf, "STARTTLS") == 0)
 	{
 		if (!have_starttls())	return (-1);
-		if (starttls(tag))		return (-1);
+		if (starttls(tag))		return (-2);
 		putenv("IMAP_STARTTLS=NO");
 		putenv("IMAP_TLS_REQUIRED=0");
 		putenv("IMAP_TLS=1");
@@ -440,6 +423,7 @@ int main(int argc, char **argv)
 	alarm(60);
 	imapd=argv[1];
 	defaultmaildir=argv[2];
+	initcapability();
 
 	ip=getenv("TCPREMOTEIP");
 	if (!ip)
