@@ -2,7 +2,7 @@
 #define	imaptoken_h
 
 /*
-** Copyright 1998 - 1999 Double Precision, Inc.
+** Copyright 1998 - 2003 Double Precision, Inc.
 ** See COPYING for distribution information.
 */
 
@@ -10,7 +10,7 @@
 #include	<stdlib.h>
 #include	<time.h>
 
-static const char imaptoken_h_rcsid[]="$Id: imaptoken.h,v 1.5 2001/10/01 23:06:33 mrsam Exp $";
+static const char imaptoken_h_rcsid[]="$Id: imaptoken.h,v 1.9 2003/07/24 16:26:47 mrsam Exp $";
 
 struct imaptoken {
 	short	tokentype;
@@ -36,13 +36,26 @@ struct imaptoken *currenttoken(void);
 struct imaptoken *nexttoken_nouc(void);
 struct imaptoken *nexttoken_noparseliteral(void);
 struct imaptoken *nexttoken_okbracket(void);
+struct imaptoken *nexttoken_nouc_okbracket(void);
 
 int ismsgset(struct imaptoken *);
 	/* See if this token is a syntactically valid message set */
+int ismsgset_str(const char *);
+	/* Ditto */
+
 void read_timeout(time_t);
 void read_eol();
 void unread(int);
 
+extern size_t doread(char *buf, size_t bufsiz);
+extern char *imap_readptr;
+extern size_t imap_readptrleft;
+extern void readfill();
+
+#define	READ()	( imap_readptrleft ? \
+	(--imap_readptrleft, (int)(unsigned char)*imap_readptr++): \
+	(readfill(), --imap_readptrleft, (int)(unsigned char)*imap_readptr++))
+
 void read_string(char **, unsigned long *, unsigned long);
 
 /* Flags */
@@ -56,10 +69,21 @@ struct imapflags {
 	char	recent;
 	} ;
 
+struct imapkeywords {
+	struct imapflags flags;
+
+	struct imapkeyword *first_keyword, *last_keyword;
+};
+
 /* ATOMS have the following maximum length */
 
 #define	IT_MAX_ATOM_SIZE	16384
 
 char *my_strdup(const char *s);
 
+
+/* SMAP */
+
+void smap_readline(char *buffer, size_t bufsize);
+
 #endif
