@@ -1,8 +1,8 @@
 /*
-** Copyright 1998 - 2007 Double Precision, Inc.
+** Copyright 1998 - 2009 Double Precision, Inc.
 ** See COPYING for distribution information.
 **
-** $Id: pop3dserver.c,v 1.42 2008/01/05 02:58:36 mrsam Exp $
+** $Id: pop3dserver.c,v 1.43 2009/03/23 11:00:44 mrsam Exp $
 */
 
 #if	HAVE_CONFIG_H
@@ -839,7 +839,7 @@ static void acctout(const char *disc)
 	strcat(p, msg6);
 	strcat(p, num3);
 
-	if ((q=getenv("POP3_STLS")) && atoi(q))
+	if ((q=getenv("POP3_TLS")) && atoi(q))
 		strcat(p, msg7);
 
 	strcat(p, "\n");
