@@ -1,5 +1,5 @@
 /*
-** Copyright 1998 - 2003 Double Precision, Inc.
+** Copyright 1998 - 2008 Double Precision, Inc.
 ** See COPYING for distribution information.
 */
 
@@ -28,7 +28,7 @@
 #include	"imaptoken.h"
 #include	"imapscanclient.h"
 
-static const char rcsid[]="$Id: search.c,v 1.31 2004/09/02 01:35:04 mrsam Exp $";
+static const char rcsid[]="$Id: search.c,v 1.33 2008/09/20 12:48:29 mrsam Exp $";
 
 extern time_t rfc822_parsedt(const char *);
 extern struct imapscaninfo current_maildir_info;
@@ -236,6 +236,16 @@ int	rc;
 
 				fill_search_body(sihead, mycharset, rfcp, fp,
 					current_maildir_info.msgs+i);
+
+				/*
+				** If there are still UNKNOWN nodes, change
+				** them to fail.
+				*/
+
+				for (p=sihead; p; p=p->next)
+					if (p->value < 0)
+						p->value=0;
+
 				rc=search_evaluate(si);
                                 rfc2045_free(rfcp);
 			}
@@ -1034,6 +1044,15 @@ int	rc;
 	}
 	rfc2045_cdecode_start(rfcp, search_body_func, &slb);
 
+	for (sip=si; sip; sip=sip->next)
+		if ((sip->type == search_text || sip->type == search_body)
+		    && sip->bs
+		    && sip->value <= 0)
+		{
+			si->value=0;
+			maildir_search_reset(&si->sei);
+		}
+
 	rc=0;
 	while (start_body < end_pos)
 	{
