@@ -1,9 +1,9 @@
 /*
-** Copyright 1998 - 2003 Double Precision, Inc.
+** Copyright 1998 - 2006Double Precision, Inc.
 ** See COPYING for distribution information.
 */
 
-/* $Id: maildirmake.c,v 1.10 2004/01/11 02:47:33 mrsam Exp $ */
+/* $Id: maildirmake.c,v 1.11 2006/09/20 01:41:27 mrsam Exp $ */
 
 #if	HAVE_CONFIG_H
 #include	"config.h"
@@ -204,6 +204,7 @@ int	musthavefolder=0;
 int	subdirperm;
 char	*addshared=0, *delshared=0;
 const char *quota=0;
+char	*tmp=0;
 
 	for (argn=1; argn<argc; argn++)
 	{
@@ -302,7 +303,7 @@ const char *quota=0;
 	{
 		if ((p=(char *)malloc(strlen(maildir)+strlen(folder)+4)) == 0)
 		{
-			perror("maildirmake");
+			perror("maildirmake malloc");
 			exit(1);
 		}
 		strcat(strcat(strcpy(p, maildir), "/."), folder);
@@ -321,7 +322,13 @@ const char *quota=0;
 	umask(0);
 	if (maildir_make(maildir, perm & ~0022, subdirperm, folder ? 1:0) < 0)
 	{
-		perror("maildirmake");
+		tmp=(char *)malloc(strlen(maildir)+14);
+		if (!tmp) {
+			perror("maildirmake malloc");
+			exit(1);
+		}
+		snprintf(tmp, 14+strlen(maildir), "maildirmake: %s", maildir);
+		perror(tmp);
 		exit(1);
 	}
 	exit(0);
