@@ -1,5 +1,5 @@
 /*
-** Copyright 2001-2006 Double Precision, Inc.
+** Copyright 2001-2007 Double Precision, Inc.
 ** See COPYING for distribution information.
 */
 
@@ -60,7 +60,9 @@ static void usage()
 		"    -t filename        - text autoresponse\n"
 		"    -c charset         - text MIME character set (default " RFC2045CHARSET ")\n"
 		"    -m filename        - text autoresponse with a MIME header\n"
-		"    -r addr1,addr2...  - any 'addr' required in a To/Cc header\n"
+		"    -r addr1,addr2...  - any 'addr' required in a To/Cc header\n");
+
+	fprintf(stderr,
 		"    -d $pathname       - database to prevent duplicate autoresponses\n"
 		"    -D x               - at least 'x' days before dupes (default: 1)\n"
 		"    -s subject         - Subject: on autoresponses\n"
@@ -196,13 +198,19 @@ static void check_dsn()
 	p=hdr("precedence");
 
 	if (strncasecmp(p, "junk", 4) == 0 ||
-	    strncasecmp(p, "bulk", 4) == 0)
+	    strncasecmp(p, "bulk", 4) == 0 ||
+	    strncasecmp(p, "list", 4) == 0)
 		exit(0);	/* Just in case */
 
 	p=hdr("auto-submitted");
 
 	if (*p && strcmp(p, "no"))
 		exit(0);
+
+	p=hdr("list-id");
+
+	if (*p)
+		exit(0);
 }
 
 /*
