@@ -3,7 +3,7 @@
 ** distribution information.
 */
 
-static const char rcsid[]="$Id: pcp.c,v 1.8 2007/07/01 19:37:05 mrsam Exp $";
+static const char rcsid[]="$Id: pcp.c,v 1.9 2009/06/27 16:32:38 mrsam Exp $";
 
 #include "config.h"
 #include <stdio.h>
@@ -1616,7 +1616,10 @@ static void usage()
 			"   -C charset   - specify your local charset (default %s)\n"
 			"   -m           - standard input is already a MIME-formatted message\n"
 			"   -e           - list event ids\n"
-			"\n"
+			"\n"), RFC2045CHARSET);
+
+	fprintf(stderr, "%s",
+		gettext(
 			"Commands:\n"
 			"   init\n"
 			"   login USERID\n"
@@ -1631,8 +1634,7 @@ static void usage()
 			"   sconnect [/pathname]\n"
 			"   setacl [MODIFY|CONFLICT|LIST|RETR|NONE]*\n"
 			"   listacl\n"
-			), RFC2045CHARSET
-		);
+			));
 	exit(1);
 }
 
