@@ -5,7 +5,7 @@
 
 
 /*
-** $Id: pcpdauthme.c,v 1.3 2004/05/02 03:25:53 mrsam Exp $
+** $Id: pcpdauthme.c,v 1.4 2006/05/28 15:29:52 mrsam Exp $
 */
 
 #include	"config.h"
@@ -52,7 +52,8 @@ FILE	*f;
 		{
 		char *p;
 
-			fgets(buf, sizeof(buf), f);
+			if (fgets(buf, sizeof(buf), f) == NULL)
+				buf[0]=0;
 			fclose(f);
 
 			if ((p=strchr(buf, '\n')) != 0)
