@@ -3,7 +3,7 @@
 ** distribution information.
 */
 
-static const char rcsid[]="$Id: pcpdir.c,v 1.8 2006/01/23 23:22:10 mrsam Exp $";
+static const char rcsid[]="$Id: pcpdir.c,v 1.9 2006/05/28 15:29:52 mrsam Exp $";
 
 #include "config.h"
 #include <stdio.h>
@@ -1113,7 +1113,8 @@ static int lb_remove_field(struct line_buffer *pi,
 		if (!cc) cc=cp+strlen(cp);
 
 		putc('\t', nfp);
-		fwrite(cp, cc-cp, 1, nfp);
+		if (fwrite(cp, cc-cp, 1, nfp) != 1)
+			break;
 	}
 	if (newfield)
 	{
