@@ -24,7 +24,7 @@
 #endif
 #endif
 
-static const char rcsid[]="$Id: spf.c,v 1.8 2006/04/12 23:00:26 mrsam Exp $";
+static const char rcsid[]="$Id: spf.c,v 1.10 2008/01/29 03:55:28 mrsam Exp $";
 
 static void set_err_msg(char *errmsg_buf,
 			size_t errmsg_buf_size,
@@ -998,7 +998,7 @@ static char lookup(struct rfc1035_spf_info *info)
 	{
 		set_err_msg(info->errmsg_buf, info->errmsg_buf_size,
 			    "Maximum of 20 nested SPF queries exceeded.");
-		return SPF_FAIL;
+		return SPF_UNKNOWN;
 	}
 
 	c=rfc1035_spf_gettxt(info->current_domain, record);
@@ -1390,7 +1390,7 @@ static char *transform(char *macro,
 	** number, but MUST support at least a value of 9.
 	*/
 
-	if (transformer_count > n)
+	if (transformer_count > n || transformer_count <= 0)
 		transformer_count=n;
 
 	if (transformer_reverse)
