@@ -567,7 +567,7 @@ SSL_CTX *tls_create(int isserver, const struct tls_info *info)
 	SSL_CTX_set_options(ctx, SSL_OP_ALL);
 
 	if (!ssl_cipher_list)
-		ssl_cipher_list="SSLv3:TLSv1:!SSLv2:HIGH:!LOW:!MEDIUM:!EXP:!NULL@STRENGTH";
+		ssl_cipher_list="SSLv3:TLSv1:!SSLv2:HIGH:!LOW:!MEDIUM:!EXP:!NULL:!aNULL@STRENGTH";
 
 	SSL_CTX_set_cipher_list(ctx, ssl_cipher_list);
 	SSL_CTX_set_timeout(ctx, session_timeout);
@@ -1432,6 +1432,7 @@ int tls_validate_pem_cert(const char *buf, size_t buf_size)
 	BIO *certbio;
 	int err;
 	EVP_PKEY *pk;
+	X509 *x;
 
 	ERR_clear_error();
 
@@ -1441,7 +1442,7 @@ int tls_validate_pem_cert(const char *buf, size_t buf_size)
 	if (!certbio)
 		return (0);
 
-	X509 *x=PEM_read_bio_X509(certbio, NULL, NULL, NULL);
+	x=PEM_read_bio_X509(certbio, NULL, NULL, NULL);
 
 	if (x)
 	{
