@@ -4,7 +4,7 @@
 */
 
 /*
-** $Id: addressbook.c,v 1.13 2006/07/16 02:00:38 mrsam Exp $
+** $Id: addressbook.c,v 1.14 2008/06/14 14:42:51 mrsam Exp $
 */
 
 #include	"sqwebmail.h"
@@ -25,6 +25,38 @@ extern void output_attrencoded_fp(const char *, FILE *);
 extern void output_urlencoded(const char *);
 extern void print_safe(const char *);
 
+static char *q_escape(const char *name)
+{
+	char *names;
+	const char *cp;
+	size_t namelen;
+	char *p;
+
+	namelen=1;
+
+	for (cp=name; *cp; ++cp, ++namelen)
+		if (*cp == '"' || *cp == '\\')
+			++namelen;
+
+	names=malloc(namelen);
+	if (!names)
+	{
+		enomem();
+	}
+
+	for (p=names, cp=name; *cp; ++cp)
+	{
+		if (iscntrl((int)(unsigned char)*cp))	continue;
+
+		if (*cp == '"' || *cp == '\\')
+			*p++='\\';
+		*p++= *cp;
+	}
+	*p=0;
+
+	return names;
+}
+
 /*
 ** When adding a new name/address pair into the address book delete
 ** bad characters from both.
@@ -33,22 +65,10 @@ extern void print_safe(const char *);
 static void fix_nameaddr(const char *name, const char *addr,
 	char **nameret, char **addrret)
 {
-char *names, *addresss;
-char	*p, *q;
+	char *names, *addresss;
+	char	*p, *q;
 
-	names=strdup(name);
-	if (!names)
-	{
-		enomem();
-	}
-
-	for (p=q=names; *p; p++)
-	{
-		if (iscntrl((int)(unsigned char)*p))	continue;
-		if (*p == '"' || *p == '\\')	continue;
-		*q++=*p;
-	}
-	*q=0;
+	names=q_escape(name);
 
 	if ((addresss=strdup(addr)) == 0)
 	{
@@ -519,9 +539,11 @@ void ab_nameaddr_show(const char *name, const char *addr)
 {
 	if (name)
 	{
+		char *q=q_escape(name);
 		printf("\"");
-		print_safe(name);
+		print_safe(q);
 		printf("\"&nbsp;");
+		free(q);
 	}
 	printf("&lt;");
 	if (addr)
@@ -814,8 +836,13 @@ int	replace_index=0;
 							** here.
 							*/
 						{
+							char *t;
+
 							printf("\"");
-							output_attrencoded(s);
+
+							t=q_escape(s);
+							printf("%s", t);
+							free(t);
 							free(s);
 							printf("\"");
 						}
