@@ -1,11 +1,11 @@
 /*
-** Copyright 1998 - 2006 Double Precision, Inc.  See COPYING for
+** Copyright 1998 - 2009 Double Precision, Inc.  See COPYING for
 ** distribution information.
 */
 
 
 /*
-** $Id: maildir.c,v 1.88 2008/07/20 03:15:08 mrsam Exp $
+** $Id: maildir.c,v 1.89 2009/06/12 11:09:50 mrsam Exp $
 */
 #include	"config.h"
 #include	<stdio.h>
@@ -799,7 +799,7 @@ char *filename=maildir_find(folder, msgid);
 
 				if (filesize > 0)
 					maildir_quota_deleted(".",
-							      -(long)filesize,
+							      -(off_t)filesize,
 							      -1);
 			}
 			free(d);
@@ -890,7 +890,7 @@ static int do_msgmove(const char *from,
 		{
 
 			if (!from_shared)
-				maildir_quota_deleted(".", -filesize, -1);
+				maildir_quota_deleted(".", -(off_t)filesize, -1);
 		}
 		else if (!dest_shared && maildirquota_countfolder(destdir) &&
 			 (from_shared || !maildirquota_countfolder(fromdir))
@@ -1214,7 +1214,7 @@ static void maildir_checknew(const char *folder, const char *dir)
 
 				if (filesize > 0)
 					maildir_quota_deleted(".",
-							      -(long)filesize,
+							      -(off_t)filesize,
 							      -1);
 			}
 
@@ -1425,7 +1425,7 @@ void maildir_autopurge()
 
 				if (filesize > 0)
 					maildir_quota_deleted(".",
-							      -(long)filesize,
+							      -(off_t)filesize,
 							      -1);
 			}
 
@@ -2895,7 +2895,7 @@ int	maildir_closemsg(int n,	/* File descriptor */
 			{
 				if (isok < 0) /* Force it */
 				{
-					maildir_quota_deleted(".", (long)
+					maildir_quota_deleted(".", (off_t)
 							      (stat_buf.st_size
 							       -prevsize),
 							      prevsize == 0
@@ -2910,7 +2910,7 @@ int	maildir_closemsg(int n,	/* File descriptor */
 		}
 		else if (prevsize != stat_buf.st_size)
 		{
-			maildir_quota_deleted(".", (long)
+			maildir_quota_deleted(".", (off_t)
 					      (stat_buf.st_size-prevsize),
 					      prevsize == 0 ? 1:0);
 		}
