@@ -1,11 +1,11 @@
 /*
-** $Id: maildir.h,v 1.15 2001/10/06 16:32:48 mrsam Exp $
+** $Id: maildir.h,v 1.18 2004/02/17 00:58:24 mrsam Exp $
 */
 #ifndef	maildir_h
 #define	maildir_h
 
 /*
-** Copyright 1998 - 1999 Double Precision, Inc.  See COPYING for
+** Copyright 1998 - 2002 Double Precision, Inc.  See COPYING for
 ** distribution information.
 */
 
@@ -51,11 +51,13 @@ extern char *maildir_readheader_mimepart(FILE *, char **, int,
 extern char *maildir_readline(FILE *);
 extern char *maildir_readheader_nolc(FILE *, char **);
 
+extern void maildir_listfolders(const char *inbox_name,
+				const char *homedir, char ***);
 extern void maildir_readfolders(char ***);
 extern void maildir_freefolders(char ***);
 extern int maildir_create(const char *);
 extern int maildir_delete(const char *, int);
-extern int maildir_rename(const char *, const char *);
+extern int maildir_rename_wrapper(const char *, const char *);
 
 extern int maildir_createmsg(const char *, const char *, char **);
 extern int maildir_recreatemsg(const char *, const char *, char **);
@@ -63,6 +65,8 @@ extern void maildir_writemsg(int, const char *, size_t);
 extern void maildir_writemsgstr(int, const char *);
 extern int maildir_closemsg(int, const char *, const char *, int,
 	unsigned long);
+extern void listrights();
+extern void getacl();
 
 /*
 ** Hack: to correctly set Content-Transfer-Encoding: header on sent mail,
