@@ -4,7 +4,7 @@
 */
 
 /*
-** $Id: msg2html.c,v 1.6 2007/07/11 01:35:49 mrsam Exp $
+** $Id: msg2html.c,v 1.7 2008/07/20 03:15:08 mrsam Exp $
 */
 
 #include "msg2html.h"
@@ -308,16 +308,10 @@ static void showmsgrfc822_addressheader(struct msg2html_info *info,
 	sai.curindex=0;
 	sai.isfirstchar=1;
 
-#if HAVE_SQWEBMAIL_UNICODE
 
 	rfc2047_print_unicode(rfca, info->output_character_set,
 			      showaddressheader_printc,
 			      showaddressheader_printsep, &sai);
-#else
-	rfc2047_print(rfca, info->output_character_set,
-		      showaddressheader_printc, showaddressheader_printsep,
-		      &sai);
-#endif
 	if (!sai.isfirstchar)
 		showaddressheader_printsep("", &sai);
 	/* This closes the final </a> */
@@ -455,12 +449,10 @@ off_t	start_pos, end_pos, start_body;
 struct	rfc2045id *p, newpart;
 off_t	dummy;
 off_t	pos;
-#if HAVE_SQWEBMAIL_UNICODE
 const struct unicode_info *uiptr=unicode_find(info->output_character_set);
 
 	if (!uiptr)
 		uiptr=&unicode_ISO8859_1;
-#endif
 
 	rfc2045_mimepos(rfc, &start_pos, &end_pos, &start_body, &dummy, &dummy);
 	if (fseek(fp, start_pos, SEEK_SET) < 0)
@@ -505,14 +497,8 @@ const struct unicode_info *uiptr=unicode_find(info->output_character_set);
 		{
 			if (save_subject)	free(save_subject);
 
-#if HAVE_SQWEBMAIL_UNICODE
 			save_subject=rfc2047_decode_unicode(value, uiptr,
 				RFC2047_DECODE_REPLACE);
-#else
-			save_subject=
-				rfc2047_decode_enhanced(value,
-							info->output_character_set);
-#endif
 			free(header);
 			continue;
 		}
@@ -624,9 +610,7 @@ const char	*dummy;
 off_t start_pos, end_pos, start_body;
 off_t dummy2;
 char	*content_name;
-#if	HAVE_SQWEBMAIL_UNICODE
 const struct unicode_info *uiptr=unicode_find(info->output_character_set);
-#endif
 
 	id=id;
 	rfc2045_mimeinfo(rfc, &content_type, &dummy, &dummy);
@@ -643,30 +627,18 @@ const struct unicode_info *uiptr=unicode_find(info->output_character_set);
 		return;
 	}
 
-#if	HAVE_SQWEBMAIL_UNICODE
 	if (rfc2231_udecodeType(rfc, "name", uiptr, &content_name) < 0 ||
 	    rfc2231_udecodeDisposition(rfc, "filename", uiptr,
 				       &content_name) < 0)
 		content_name=NULL;
-#else
-	if (rfc2231_decodeType(rfc, "name", NULL, NULL, &content_name) < 0 ||
-	    rfc2231_decodeDisposition(rfc, "filename", NULL, NULL,
-				      &content_name) < 0)
-		content_name=NULL;
-#endif
 	if (!content_name &&
 	    ((cn=rfc2045_getattr(rfc->content_type_attr, "name")) ||
 	     (cn=rfc2045_getattr(rfc->content_disposition_attr,
 				 "filename"))) &&
 	    strstr(cn, "=?") && strstr(cn, "?="))
 	    /* RFC2047 header encoding (not compliant to RFC2047) */
-#if	HAVE_SQWEBMAIL_UNICODE
 		content_name = rfc2047_decode_unicode(cn, uiptr,
 			RFC2047_DECODE_ABORT);
-#else
-		content_name = rfc2047_decode_enhanced(cn,
-			info->output_character_set);
-#endif
 
 	rfc2045_mimepos(rfc, &start_pos, &end_pos, &start_body,
 			&dummy2, &dummy2);
@@ -1097,16 +1069,10 @@ static void showtexthtml(FILE *fp, struct rfc2045 *rfc, struct rfc2045id *id,
 
 		printf("<table border=\"0\" cellpadding=\"0\" cellspacing=\"0\" width=\"100%%\"><tr><td>\n");
 
-#if HAVE_SQWEBMAIL_UNICODE
 		rfc2045_decodetextmimesection(fileno(fp), rfc,
 					      info->output_character_set,
 					      &htmlfilter_stub,
 					      hf_info);
-#else
-		rfc2045_decodemimesection(fileno(fp), rfc,
-					  &htmlfilter_stub,
-					  hf_info);
-#endif
 
 		printf("</td></tr>");
 
@@ -1419,16 +1385,10 @@ static void showtextplain(FILE *fp, struct rfc2045 *rfc, struct rfc2045id *id,
 			     &showtextplainfunc, info);
 	}
 
-#if HAVE_SQWEBMAIL_UNICODE
 	rc=rfc2045_decodetextmimesection(fileno(fp), rfc,
 					 info->output_character_set,
 					 &filter_stub,
 					 &tinfo);
-#else
-	rc=rfc2045_decodemimesection(fileno(fp), rfc,
-				     &filter_stub,
-				     &tinfo);
-#endif
 	fseek(fp, 0L, SEEK_END);
 	fseek(fp, 0L, SEEK_SET);	/* Resync stdio with uio */
 
