@@ -5,7 +5,7 @@
 
 
 /*
-** $Id: newmsg.c,v 1.66 2007/08/30 01:38:49 mrsam Exp $
+** $Id: newmsg.c,v 1.67 2008/07/20 03:15:08 mrsam Exp $
 */
 #include	"config.h"
 #include	"sqwebmail.h"
@@ -43,9 +43,7 @@
 #endif
 #include	<errno.h>
 #include	"htmllibdir.h"
-#if	HAVE_SQWEBMAIL_UNICODE
 #include	"unicode/unicode.h"
-#endif
 
 extern const char *sqwebmail_content_charset;
 extern int spell_start(const char *);
@@ -73,9 +71,7 @@ static void newmsg_header(const char *label, const char *field,
 int		hdrmaxlen=512;
 const char	*p=getarg("HDRMAXLEN");
 
-#if	HAVE_SQWEBMAIL_UNICODE
 const struct unicode_info *uiptr=unicode_find(sqwebmail_content_charset);
-#endif
 
 	if (p && (atoi(p) > hdrmaxlen))
 		hdrmaxlen=atoi(p);
@@ -92,12 +88,8 @@ const struct unicode_info *uiptr=unicode_find(sqwebmail_content_charset);
 	{
 	char	*s;
 
-#if	HAVE_SQWEBMAIL_UNICODE
 		s=rfc2047_decode_unicode(encoded, uiptr,
 			RFC2047_DECODE_NOTAG|RFC2047_DECODE_REPLACE);
-#else
-		s=rfc2047_decode_simple(encoded);
-#endif
 		if (!s)	enomem();
 		output_attrencoded(s);
 		free(s);
@@ -146,14 +138,9 @@ const char	*p=getarg("HDRMAXLEN");
 
 		if (a)
 		{
-#if HAVE_SQWEBMAIL_UNICODE
 			rfc2047_print_unicode(a, sqwebmail_content_charset,
 					      printc,
 					      printsep, NULL);
-#else
-			rfc2047_print(a, sqwebmail_content_charset,
-				      printc, printsep, NULL);
-#endif
 			rfc822a_free(a);
 		}
 
@@ -355,14 +342,9 @@ void newmsg_showfp(FILE *fp, int *attachcnt)
 
 	textarea_eol=1;
 	if (q)
-#if	HAVE_SQWEBMAIL_UNICODE
 		rfc2045_decodetextmimesection(fileno(fp), q,
 					      sqwebmail_content_charset,
 					      &show_textarea, NULL);
-#else
-		rfc2045_decodemimesection(fileno(fp), q,
-					  &show_textarea, NULL);
-#endif
 	rfc2045_free(p);
 }
 
@@ -688,7 +670,6 @@ void newmsg_init(const char *folder, const char *pos)
 		       "name=\"dsn\" id=\"dsn\" /></td><td><label for=\"dsn\">%s</label></td></tr>\n",
 		       getarg("DSN"));
 
-#if HAVE_SQWEBMAIL_UNICODE
 	if (libmail_gpg_has_gpg(GPGDIR) == 0)
 	{
 		char *all_addr;
@@ -716,7 +697,6 @@ void newmsg_init(const char *folder, const char *pos)
 		if (all_addr)
 			free(all_addr);
 	}
-#endif
 
 	if (fp)
 		fclose(fp);
