@@ -10,7 +10,7 @@
 #include	<string.h>
 #include	<stdio.h>
 
-static const char rcsid[]="$Id: rfc2646html.c,v 1.11 2007/07/11 01:35:49 mrsam Exp $";
+static const char rcsid[]="$Id: rfc2646html.c,v 1.12 2009/01/27 00:53:16 mrsam Exp $";
 
 /*
 ** Flowed-text format processing (see RFC2646).
@@ -198,7 +198,7 @@ static const char *rfc2646_getpfix(struct rfc2646parser *p, int isflowed,
 			"<div class=\"quotedtext\">",
 			r->current_quote_depth % 3);
 
-		rc=(*r->handler)(str, strlen(str), p->voidarg);
+		rc=(*r->handler)(str, strlen(str), r->voidarg);
 
 		if (rc)
 			return (NULL);
