@@ -5,7 +5,7 @@
 
 
 /*
-** $Id: sqwebmail.c,v 1.144 2008/02/03 15:25:07 mrsam Exp $
+** $Id: sqwebmail.c,v 1.146 2009/02/04 23:53:32 mrsam Exp $
 */
 #include	"sqwebmail.h"
 #include	"sqconfig.h"
@@ -48,7 +48,6 @@
 #if	HAVE_LOCALE_H
 #if	HAVE_SETLOCALE
 #include	<locale.h>
-#if	HAVE_SQWEBMAIL_UNICODE
 #if	USE_LIBCHARSET
 #if	HAVE_LOCALCHARSET_H
 #include	<localcharset.h>
@@ -58,7 +57,6 @@
 #elif	HAVE_LANGINFO_CODESET
 #include	<langinfo.h>
 #endif	/* USE_LIBCHARSET */
-#endif	/* HAVE_SQWEBMAIL_UNICODE */
 #endif	/* HAVE_SETLOCALE */
 #endif	/* HAVE_LOCALE_H */
 #include	<ctype.h>
@@ -1984,24 +1982,12 @@ void cleanup()
 	}
 #endif
 
-#if HAVE_SQWEBMAIL_UNICODE
 	libmail_gpg_cleanup();
-#endif
 	freeargs();
 	sqpcp_close();
 }
 
-#if HAVE_SQWEBMAIL_UNICODE
 
-#else
-
-/* Head it off at the pass */
-
-int libmail_gpg_has_gpg(const char *dummy)
-{
-	return (-1);
-}
-#endif
 
 static RETSIGTYPE catch_sig(int n)
 {
@@ -2046,7 +2032,6 @@ char	*cl=http11_best_content_language(templatedir,
 #if	HAVE_LOCALE_H
 #if	HAVE_SETLOCALE
 	setlocale(LC_ALL, sqwebmail_content_locale);
-#if	HAVE_SQWEBMAIL_UNICODE
 #if	USE_LIBCHARSET
 	setlocale(LC_CTYPE, sqwebmail_content_locale);
 	sqwebmail_system_charset = locale_charset();
@@ -2056,7 +2041,6 @@ char	*cl=http11_best_content_language(templatedir,
 #else
 	sqwebmail_system_charset = NULL;
 #endif	/* USE_LIBCHARSET */
-#endif	/* HAVE_SQWEBMAIL_UNICODE */
 	setlocale(LC_CTYPE, "C");
 	setlang();
 #endif
@@ -2219,6 +2203,17 @@ time_t	timeouthard=get_timeouthard();
 
 	ip_addr=getenv("REMOTE_ADDR");
 
+#if 0
+	{
+		FILE *f;
+
+		f=fopen("/tmp/pid", "w");
+		fprintf(f, "%d\n", (int)getpid());
+		fclose(f);
+		sleep(10);
+	}
+#endif
+
 	/*
 	 * Note: if we get a signal during FastCGI processing, this means
 	 * means we need to terminate so that the webserver can respawn us.
@@ -2409,7 +2404,6 @@ time_t	timeouthard=get_timeouthard();
 #if	HAVE_LOCALE_H
 #if	HAVE_SETLOCALE
 		setlocale(LC_ALL, sqwebmail_content_locale);
-#if	HAVE_SQWEBMAIL_UNICODE
 #if	USE_LIBCHARSET
 		setlocale(LC_CTYPE, sqwebmail_content_locale);
 		sqwebmail_system_charset = locale_charset();
@@ -2419,7 +2413,6 @@ time_t	timeouthard=get_timeouthard();
 #else
 		sqwebmail_system_charset = NULL;
 #endif  /* USE_LIBCHARSET */
-#endif	/* HAVE_SQWEBMAIL_UNICODE */
 		setlocale(LC_CTYPE, "C");
 		setlang();
 #endif
@@ -2547,7 +2540,6 @@ time_t	timeouthard=get_timeouthard();
 #if	HAVE_LOCALE_H
 #if	HAVE_SETLOCALE
 				setlocale(LC_ALL, sqwebmail_content_locale);
-#if	HAVE_SQWEBMAIL_UNICODE
 #if	USE_LIBCHARSET
 				setlocale(LC_CTYPE, sqwebmail_content_locale);
 				sqwebmail_system_charset = locale_charset();
@@ -2557,7 +2549,6 @@ time_t	timeouthard=get_timeouthard();
 #else
 				sqwebmail_system_charset = NULL;
 #endif	/* USE_LIBCHARSET */
-#endif	/* HAVE_SQWEBMAIL_UNICODE */
 				setlocale(LC_CTYPE, "C");
 				setlang();
 #endif
